==> symfony_5.4.4+dfsg.orig.tar.xz: symfony-5.4.4/src/Symfony/Component/Intl/Resources/data/scripts/th.php <==
<?php

return [
    'Names' => [
        'Afak' => 'อะฟาคา',
        'Aghb' => 'แอลเบเนีย คอเคเซีย',
        'Arab' => 'อาหรับ',
        'Armi' => 'อิมพีเรียล อราเมอิก',
        'Armn' => 'อาร์เมเนีย',
        'Avst' => 'อเวสตะ',
        'Bali' => 'บาหลี',
        'Bamu' => 'บามุม',
        'Bass' => 'บัสซา',
        'Batk' => 'บาตัก',
        'Beng' => 'เบงกาลี',
        'Blis' => 'บลิสซิมโบลส์',
        'Bopo' => 'ปอพอมอฟอ',
        'Brah' => 'พราหมี',
        'Brai' => 'เบรลล์',
        'Bugi' => 'บูกิส',
        'Buhd' => 'บูฮิด',
        'Cakm' => 'ชากมา',
        'Cans' => 'สัญลักษณ์ชนเผ่าพื้นเมืองแคนาดา',
        'Cari' => 'คาเรีย',
        'Cham' => 'จาม',
        'Cher' => 'เชอโรกี',
        'Cirt' => 'เซิร์ท',
        'Copt' => 'คอปติก',
        'Cprt' => 'ไซเปรียท',
        'Cyrl' => 'ซีริลลิก',
        'Cyrs' => 'เชอร์ชสลาโวนิกซีริลลิกโบราณ',
        'Deva' => 'เทวนาครี',
        'Dsrt' => 'เดเซเรท',
        'Dupl' => 'ชวเลขดัปโลยัน',
        'Egyd' => 'ดีโมติกอียิปต์',
        'Egyh' => 'เฮียราติกอียิปต์',
        'Egyp' => 'เฮียโรกลิฟส์อียิปต์',
        'Elba' => 'เอลบ์ซาน',
        'Ethi' => 'เอธิโอปิก',
        'Geok' => 'คัตซูรีจอร์เจีย',
        'Geor' => 'จอร์เจีย',
        'Glag' => 'กลาโกลิติก',
        'Goth' => 'โกธิก',
        'Gran' => 'คฤณห์',
        'Grek' => 'กรีก',
        'Gujr' => 'คุชราต',
        'Guru' => 'กูร์มูคี',
        'Hanb' => 'จีนกลาง',
        'Hang' => 'ฮันกึล',
        'Hani' => 'ฮั่น',
        'Hano' => 'ฮานูโนโอ',
        'Hans' => 'ตัวย่อ',
        'Hant' => 'ตัวเต็ม',
        'Hebr' => 'ฮีบรู',
        'Hira' => 'ฮิระงะนะ',
        'Hluw' => 'อักขระอานาโตเลีย',
        'Hmng' => 'ปาเฮาห์ม้ง',
        'Hrkt' => 'คะตะกะนะหรือฮิระงะนะ',
        'Hung' => 'ฮังการีโบราณ',
        'Inds' => 'อินดัส',
        'Ital' => 'อิตาลีโบราณ',
        'Jamo' => 'จาโม',
        'Java' => 'ชวา',
        'Jpan' => 'ญี่ปุ่น',
        'Jurc' => 'จูร์เชน',
        'Kali' => 'คยาห์',
        'Kana' => 'คะตะกะนะ',
        'Khar' => 'ขโรษฐี',
        'Khmr' => 'เขมร',
        'Khoj' => 'คอจคี',
        'Knda' => 'กันนาดา',
        'Kore' => 'เกาหลี',
        'Kpel' => 'เปลเล',
        'Kthi' => 'กายติ',
        'Lana' => 'ล้านนา',
        'Laoo' => 'ลาว',
        'Latf' => 'ลาติน - ฟรังเตอร์',
        'Latg' => 'ลาติน - แกลิก',
        'Latn' => 'ละติน',
        'Lepc' => 'เลปชา',
        'Limb' => 'ลิมบู',
        'Lina' => 'ลีเนียร์เอ',
        'Linb' => 'ลีเนียร์บี',
        'Lisu' => 'เฟรเซอร์',
        'Loma' => 'โลมา',
        'Lyci' => 'ไลเซีย',
        'Lydi' => 'ลีเดีย',
        'Mahj' => 'มหาชนี',
        'Mand' => 'แมนเดียน',
        'Mani' => 'มานิแชน',
        'Maya' => 'มายาไฮโรกลิฟส์',
        'Mend' => 'เมนเด',
        'Merc' => 'เคอร์ซีฟ-เมโรอิติก',
        'Mero' => 'เมโรติก',
        'Mlym' => 'มาลายาลัม',
        'Modi' => 'โมฑี',
        'Mong' => 'มองโกเลีย',
        'Moon' => 'มูน',
        'Mroo' => 'มโร',
        'Mtei' => 'เมเทมาเยก',
        'Mymr' => 'พม่า',
        'Narb' => 'อาระเบียเหนือโบราณ',
        'Nbat' => 'นาบาทาเอียน',
        'Nkgb' => 'กีบา-นาซี',
        'Nkoo' => 'เอ็นโก',
        'Nshu' => 'นุซุ',
        'Ogam' => 'โอคัม',
        'Olck' => 'โอลชิกิ',
        'Orkh' => 'ออร์คอน',
        'Orya' => 'โอริยา',
        'Osma' => 'ออสมันยา',
        'Palm' => 'พาลไมรีน',
        'Pauc' => 'ป่อจิ้งฮอ',
        'Perm' => 'เปอร์มิกโบราณ',
        'Phag' => 'ฟากส์-ปา',
        'Phli' => 'ปะห์ลาวีอินสคริปชันแนล',
        'Phlp' => 'ปะห์ลาวีซอลเตอร์',
        'Phlv' => 'ปะห์ลาวีบุ๊ก',
        'Phnx' => 'ฟินิเชีย',
        'Plrd' => 'สัทศาสตร์พอลลาร์ด',
        'Prti' => 'พาร์เทียอินสคริปชันแนล',
        'Rjng' => 'เรจัง',
        'Roro' => 'รองโกรองโก',
        'Runr' => 'รูนิก',
        'Samr' => 'ซามาเรีย',
        'Sara' => 'ซาราติ',
        'Sarb' => 'อาระเบียใต้โบราณ',
        'Saur' => 'โสวรัสตระ',
        'Sgnw' => 'ไซน์ไรติ้ง',
        'Shaw' => 'ซอเวียน',
        'Shrd' => 'ชาราดา',
        'Sidd' => 'สิทธัม',
        'Sind' => 'คุดาวาดี',
        'Sinh' => 'สิงหล',
        'Sora' => 'โสราสมเป็ง',
        'Sund' => 'ซุนดา',
        'Sylo' => 'ซิโลตินากรี',
        'Syrc' => 'ซีเรีย',
        'Syre' => 'ซีเรียเอสทรานจีโล',
        'Syrj' => 'ซีเรียตะวันตก',
        'Syrn' => 'ซีเรียตะวันออก',
        'Tagb' => 'ตักบันวา',
        'Takr' => 'ทาครี',
        'Tale' => 'ไทเล',
        'Talu' => 'ไทลื้อใหม่',
        'Taml' => 'ทมิฬ',
        'Tang' => 'ตันกัท',
        'Tavt' => 'ไทเวียต',
        'Telu' => 'เตลูกู',
        'Teng' => 'เทงกวาร์',
        'Tfng' => 'ทิฟินาก',
        'Tglg' => 'ตากาล็อก',
        'Thaa' => 'ทานา',
        'Thai' => 'ไทย',
        'Tibt' => 'ทิเบต',
        'Tirh' => 'เทอฮุทา',
        'Ugar' => 'ยูการิต',
        'Vaii' => 'ไว',
        'Visp' => 'คำพูดที่มองเห็นได้',
        'Wara' => 'วารังกสิติ',
        'Wole' => 'โอลีเอ',
        'Xpeo' => 'เปอร์เซียโบราณ',
        'Xsux' => 'อักษรรูปลิ่มสุเมเรีย-อัคคาเดีย',
        'Yiii' => 'ยิ',
        'Zinh' => 'อินเฮอริต',
        'Zmth' => 'เครื่องหมายทางคณิตศาสตร์',
        'Zsye' => 'อีโมจิ',
        'Zsym' => 'สัญลักษณ์',
        'Zxxx' => 'ไม่มีภาษาเขียน',
        'Zyyy' => 'สามัญ',
    ],
];

==> symfony_8.0.2+dfsg.orig.tar.xz: symfony-8.0.2/src/Symfony/Component/Intl/Resources/data/scripts/th.php <==
<?php

return [
    'Names' => [
        'Adlm' => 'อัดลัม',
        'Afak' => 'อะฟาคา',
        'Aghb' => 'แอลเบเนีย คอเคเซีย',
        'Arab' => 'อาหรับ',
        'Aran' => 'นาสตาลิก',
        'Armi' => 'อิมพีเรียล อราเมอิก',
        'Armn' => 'อาร์เมเนีย',
        'Avst' => 'อเวสตะ',
        'Bali' => 'บาหลี',
        'Bamu' => 'บามุม',
        'Bass' => 'บัสซา',
        'Batk' => 'บาตัก',
        'Beng' => 'เบงกาลี',
        'Blis' => 'บลิสซิมโบลส์',
        'Bopo' => 'ปอพอมอฟอ',
        'Brah' => 'พราหมี',
        'Brai' => 'เบรลล์',
        'Bugi' => 'บูกิส',
        'Buhd' => 'บูฮิด',
        'Cakm' => 'จักม่า',
        'Cans' => 'อักษรพยางค์ของชาวอะบอริจินในแคนาดา',
        'Cari' => 'คาเรีย',
        'Cham' => 'จาม',
        'Cher' => 'เชอโรกี',
        'Cirt' => 'เซิร์ท',
        'Copt' => 'คอปติก',
        'Cprt' => 'ไซเปรียท',
        'Cyrl' => 'ซีริลลิก',
        'Cyrs' => 'เชอร์ชสลาโวนิกซีริลลิกโบราณ',
        'Deva' => 'เทวนาครี',
        'Dsrt' => 'เดเซเรท',
        'Dupl' => 'ชวเลขดัปโลยัน',
        'Egyd' => 'ดีโมติกอียิปต์',
        'Egyh' => 'เฮียราติกอียิปต์',
        'Egyp' => 'เฮียโรกลิฟส์อียิปต์',
        'Elba' => 'เอลบ์ซาน',
        'Ethi' => 'เอธิโอปิก',
        'Geok' => 'คัตซูรีจอร์เจีย',
        'Geor' => 'จอร์เจีย',
        'Glag' => 'กลาโกลิติก',
        'Goth' => 'โกธิก',
        'Gran' => 'คฤณห์',
        'Grek' => 'กรีก',
        'Gujr' => 'คุชราต',
        'Guru' => 'กูร์มูคี',
        'Hanb' => 'จีนกลาง',
        'Hang' => 'ฮันกึล',
        'Hani' => 'ฮั่น',
        'Hano' => 'ฮานูโนโอ',
        'Hans' => 'ตัวย่อ',
        'Hant' => 'ตัวเต็ม',
        'Hebr' => 'ฮีบรู',
        'Hira' => 'ฮิระงะนะ',
        'Hluw' => 'อักขระอานาโตเลีย',
        'Hmng' => 'ปาเฮาห์ม้ง',
        'Hrkt' => 'คะตะกะนะหรือฮิระงะนะ',
        'Hung' => 'ฮังการีโบราณ',
        'Inds' => 'อินดัส',
        'Ital' => 'อิตาลีโบราณ',
        'Jamo' => 'จาโม',
        'Java' => 'ชวา',
        'Jpan' => 'ญี่ปุ่น',
        'Jurc' => 'จูร์เชน',
        'Kali' => 'คยาห์',
        'Kana' => 'คะตะกะนะ',
        'Khar' => 'ขโรษฐี',
        'Khmr' => 'เขมร',
        'Khoj' => 'คอจคี',
        'Knda' => 'กันนาดา',
        'Kore' => 'เกาหลี',
        'Kpel' => 'เปลเล',
        'Kthi' => 'กายติ',
        'Lana' => 'ล้านนา',
        'Laoo' => 'ลาว',
        'Latf' => 'ลาติน - ฟรังเตอร์',
        'Latg' => 'ลาติน - แกลิก',
        'Latn' => 'ละติน',
        'Lepc' => 'เลปชา',
        'Limb' => 'ลิมบู',
        'Lina' => 'ลีเนียร์เอ',
        'Linb' => 'ลีเนียร์บี',
        'Lisu' => 'เฟรเซอร์',
        'Loma' => 'โลมา',
        'Lyci' => 'ไลเซีย',
        'Lydi' => 'ลีเดีย',
        'Mahj' => 'มหาชนี',
        'Mand' => 'แมนเดียน',
        'Mani' => 'มานิแชน',
        'Maya' => 'มายาไฮโรกลิฟส์',
        'Mend' => 'เมนเด',
        'Merc' => 'เคอร์ซีฟ-เมโรอิติก',
        'Mero' => 'เมโรติก',
        'Mlym' => 'มาลายาลัม',
        'Modi' => 'โมฑี',
        'Mong' => 'มองโกเลีย',
        'Moon' => 'มูน',
        'Mroo' => 'มโร',
        'Mtei' => 'เมเทมาเยก',
        'Mymr' => 'พม่า',
        'Narb' => 'อาระเบียเหนือโบราณ',
        'Nbat' => 'นาบาทาเอียน',
        'Nkgb' => 'กีบา-นาซี',
        'Nkoo' => 'เอ็นโก',
        'Nshu' => 'นุซุ',
        'Ogam' => 'โอคัม',
        'Olck' => 'โอลชิกิ',
        'Orkh' => 'ออร์คอน',
        'Orya' => 'โอริยา',
        'Osma' => 'ออสมันยา',
        'Palm' => 'พาลไมรีน',
        'Pauc' => 'ป่อจิ้งฮอ',
        'Perm' => 'เปอร์มิกโบราณ',
        'Phag' => 'ฟากส์-ปา',
        'Phli' => 'ปะห์ลาวีอินสคริปชันแนล',
        'Phlp' => 'ปะห์ลาวีซอลเตอร์',
        'Phlv' => 'ปะห์ลาวีบุ๊ก',
        'Phnx' => 'ฟินิเชีย',
        'Plrd' => 'สัทศาสตร์พอลลาร์ด',
        'Prti' => 'พาร์เทียอินสคริปชันแนล',
        'Rjng' => 'เรจัง',
        'Rohg' => 'ฮะนีฟี',
        'Roro' => 'รองโกรองโก',
        'Runr' => 'รูนิก',
        'Samr' => 'ซามาเรีย',
        'Sara' => 'ซาราติ',
        'Sarb' => 'อาระเบียใต้โบราณ',
        'Saur' => 'โสวรัสตระ',
        'Sgnw' => 'ไซน์ไรติ้ง',
        'Shaw' => 'ซอเวียน',
        'Shrd' => 'ชาราดา',
        'Sidd' => 'สิทธัม',
        'Sind' => 'คุดาวาดี',
        'Sinh' => 'สิงหล',
        'Sora' => 'โสราสมเป็ง',
        'Sund' => 'ซุนดา',
        'Sylo' => 'ซิโลตินากรี',
        'Syrc' => 'ซีเรีย',
        'Syre' => 'ซีเรียเอสทรานจีโล',
        'Syrj' => 'ซีเรียตะวันตก',
        'Syrn' => 'ซีเรียตะวันออก',
        'Tagb' => 'ตักบันวา',
        'Takr' => 'ทาครี',
        'Tale' => 'ไทเล',
        'Talu' => 'ไทลื้อใหม่',
        'Taml' => 'ทมิฬ',
        'Tang' => 'ตันกัท',
        'Tavt' => 'ไทเวียต',
        'Telu' => 'เตลูกู',
        'Teng' => 'เทงกวาร์',
        'Tfng' => 'ทิฟินาก',
        'Tglg' => 'ตากาล็อก',
        'Thaa' => 'ทานา',
        'Thai' => 'ไทย',
        'Tibt' => 'ทิเบต',
        'Tirh' => 'เทอฮุทา',
        'Ugar' => 'ยูการิต',
        'Vaii' => 'ไว',
        'Visp' => 'คำพูดที่มองเห็นได้',
        'Wara' => 'วารังกสิติ',
        'Wole' => 'โอลีเอ',
        'Xpeo' => 'เปอร์เซียโบราณ',
        'Xsux' => 'อักษรรูปลิ่มสุเมเรีย-อัคคาเดีย',
        'Yiii' => 'ยิ',
        'Zinh' => 'อินเฮอริต',
        'Zmth' => 'เครื่องหมายทางคณิตศาสตร์',
        'Zsye' => 'อีโมจิ',
        'Zsym' => 'สัญลักษณ์',
        'Zxxx' => 'ไม่มีภาษาเขียน',
        'Zyyy' => 'สามัญ',
    ],
];
